async function loadData() {
  const res = await fetch(
    'https://gist.githubusercontent.com/Rekha-Telkapally/bc3a0418dcc508f08d2b9d6e9f1eb55d/raw/6f01140301581538c3df61c7f9fe950fe7547e96/CottonProduction.csv',
  );
  const textformat = await res.text();
  const dataset = parseCSVData(textformat);
  return dataset;
}

function parseCSVData(csvData) {
  return csvData
    .trim()
    .split('\n')
    .map((row) =>
      row.split(',').map((cell) => cell.trim()),
    );
}

function displayBarChart(data) {
  const manufacturer = data.slice(1).map((row) => row[0]);
  const units = data.slice(1).map((row) => +row[1]);

  const margin = {
    top: 60,
    right: 50,
    bottom: 80,
    left: 150,
  };
  const width = 800 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  const x = d3
    .scaleLinear()
    .domain([0, d3.max(units)])
    .range([0, width]);
  const y = d3
    .scaleBand()
    .domain(manufacturer)
    .range([0, height])
    .padding(0.1);

  const svg = d3
    .select('#chartContainer')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  svg
    .selectAll('.bar')
    .data(units)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('y', (d, i) => y(manufacturer[i]))
    .attr('height', y.bandwidth())
    .attr('width', (d) => x(d))
    .attr('fill', 'steelblue')
    .on('mouseover', function () {
      d3.select(this).attr('fill', '#6495ED');
    })
    .on('mouseout', function () {
      d3.select(this).attr('fill', 'steelblue');
    });

  svg
    .append('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0,${height})`)
    .call(
      d3
        .axisBottom(x)
        .ticks(5)
        .tickFormat(d3.format('.2s')),
    );

  svg
    .append('g')
    .attr('class', 'y-axis')
    .call(d3.axisLeft(y).tickSize(0));

  svg
    .append('text')
    .attr('class', 'x-label')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height + margin.bottom - 10)
    .text('Amount of Production (in metric tons)');

  svg
    .append('text')
    .attr('class', 'y-label')
    .attr('text-anchor', 'middle')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left + 20)
    .text('Country Manufacturing');

  svg
    .append('text')
    .attr('class', 'graph-title')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', -margin.top / 2)
    .text('Cotton Production Across the World');

  svg
    .append('text')
    .attr('class', 'data-description')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', -margin.top / 2 + 20)
    .text(
      'Manufacturer Vs Cotton Production in metric tons',
    );
}

window.onload = async () => {
  const data = await loadData();
  displayBarChart(data);
};
